@@ -5,13 +5,6 @@ from constants import X_HEX_ACCENTS, X_RGB_ACCENTS, x_hex_colors, x_rgb_colors
 from constants import Y_HEX_ACCENT1, Y_HEX_ACCENT2
 from constants import y_hex_colors1, y_hex_colors2
 
-def change_value (key, value, file):
-    if value is not None:
-        command = "sed -i '/%(key)s=/c\%(key)s=%(value)s' %(file)s" % {'key':key, 'value':value, 'file':file}
-    else:
-        command = "sed -i '/%(key)s=/d' %(file)s" % {'key':key, 'file':file}
-    os.system(command)
-
 def x_colorize_directory (path, variation):
     for accent in X_HEX_ACCENTS:
         os.system("find %s -name '*.*' -type f -exec sed -i 's/%s/%s/gI' {}  \\;" % (path, accent, x_hex_colors[variation]))
@@ -52,14 +45,9 @@ for color in os.listdir("src/Mint-X/variations"):
     path = os.path.join("src/Mint-X/variations", color)
     if os.path.isdir(path):
         theme = "usr/share/themes/Mint-X-%s" % color
-        theme_index = os.path.join(theme, "index.theme")
         os.system("cp -R usr/share/themes/Mint-X %s" % theme)
         os.system("cp -R src/Mint-X/variations/%s/* %s/" % (color, theme))
 
-        # Theme name
-        for key in ["Name", "GtkTheme", "IconTheme"]:
-            change_value(key, "Mint-X-%s" % color, theme_index)
-
         # Accent color
         gtkrc = os.path.join(theme, "gtk-2.0", "gtkrc")
         settings_ini = os.path.join(theme, "gtk-3.0", "settings.ini")
@@ -118,16 +106,8 @@ for color in y_hex_colors1.keys():
 
             # Copy theme
             theme = "usr/share/themes/%s-%s" % (original_name, color)
-            theme_index = os.path.join(theme, "index.theme")
             os.system("cp -R usr/share/themes/%s %s" % (original_name, theme))
 
-            # Theme name
-            for key in ["Name", "GtkTheme"]:
-                change_value(key, "%s-%s" % (original_name, color), theme_index)
-
-            for key in ["IconTheme"]:
-                change_value(key, "%s-%s" % (original_name, color), theme_index)
-
             # Regenerate GTK4 sass
             os.system("cp -R src/Mint-Y/gtk-4.0/sass %s/gtk-4.0/" % theme)
             y_colorize_directory("%s/gtk-4.0/sass" % theme, color)
